@@ -4,16 +4,19 @@ from __future__ import annotations
 
 import logging
 import re
+from dataclasses import dataclass
 from enum import Enum
-from typing import Optional, cast
+from typing import Annotated, cast
 
-from pydantic.v1 import BaseModel, Field, root_validator
+from mashumaro import DataClassDictMixin
+from mashumaro.config import BaseConfig
+from mashumaro.types import Alias
 
 from ..device_type import DeviceType
 from ..deviceconfig import DeviceConfig
 from ..interfaces.light import HSV, ColorTempRange
 from ..module import Module
-from ..protocol import BaseProtocol
+from ..protocols import BaseProtocol
 from .iotdevice import IotDevice, KasaException, requires_update
 from .modules import (
     Antitheft,
@@ -35,9 +38,12 @@ class BehaviorMode(str, Enum):
     Last = "last_status"
     #: Use chosen preset.
     Preset = "customize_preset"
+    #: Circadian
+    Circadian = "circadian"
 
 
-class TurnOnBehavior(BaseModel):
+@dataclass
+class TurnOnBehavior(DataClassDictMixin):
     """Model to present a single turn on behavior.
 
     :param int preset: the index number of wanted preset.
@@ -48,34 +54,30 @@ class TurnOnBehavior(BaseModel):
     to contain either the preset index, or ``None`` for the last known state.
     """
 
-    #: Index of preset to use, or ``None`` for the last known state.
-    preset: Optional[int] = Field(alias="index", default=None)  # noqa: UP007
+    class Config(BaseConfig):
+        """Serialization config."""
+
+        omit_none = True
+        serialize_by_alias = True
+
     #: Wanted behavior
     mode: BehaviorMode
-
-    @root_validator
-    def _mode_based_on_preset(cls, values):
-        """Set the mode based on the preset value."""
-        if values["preset"] is not None:
-            values["mode"] = BehaviorMode.Preset
-        else:
-            values["mode"] = BehaviorMode.Last
-
-        return values
-
-    class Config:
-        """Configuration to make the validator run when changing the values."""
-
-        validate_assignment = True
+    #: Index of preset to use, or ``None`` for the last known state.
+    preset: Annotated[int | None, Alias("index")] = None
+    brightness: int | None = None
+    color_temp: int | None = None
+    hue: int | None = None
+    saturation: int | None = None
 
 
-class TurnOnBehaviors(BaseModel):
+@dataclass
+class TurnOnBehaviors(DataClassDictMixin):
     """Model to contain turn on behaviors."""
 
     #: The behavior when the bulb is turned on programmatically.
-    soft: TurnOnBehavior = Field(alias="soft_on")
+    soft: Annotated[TurnOnBehavior, Alias("soft_on")]
     #: The behavior when the bulb has been off from mains power.
-    hard: TurnOnBehavior = Field(alias="hard_on")
+    hard: Annotated[TurnOnBehavior, Alias("hard_on")]
 
 
 TPLINK_KELVIN = {
@@ -178,8 +180,8 @@ class IotBulb(IotDevice):
 
         Bulb configuration presets can be accessed using the :func:`presets` property:
 
-        >>> bulb.presets
-        [IotLightPreset(index=0, brightness=50, hue=0, saturation=0, color_temp=2700, custom=None, id=None, mode=None), IotLightPreset(index=1, brightness=100, hue=0, saturation=75, color_temp=0, custom=None, id=None, mode=None), IotLightPreset(index=2, brightness=100, hue=120, saturation=75, color_temp=0, custom=None, id=None, mode=None), IotLightPreset(index=3, brightness=100, hue=240, saturation=75, color_temp=0, custom=None, id=None, mode=None)]
+        >>> [ preset.to_dict() for preset in bulb.presets }
+        [{'brightness': 50, 'hue': 0, 'saturation': 0, 'color_temp': 2700, 'index': 0}, {'brightness': 100, 'hue': 0, 'saturation': 75, 'color_temp': 0, 'index': 1}, {'brightness': 100, 'hue': 120, 'saturation': 75, 'color_temp': 0, 'index': 2}, {'brightness': 100, 'hue': 240, 'saturation': 75, 'color_temp': 0, 'index': 3}]
 
         To modify an existing preset, pass :class:`~kasa.interfaces.light.LightPreset`
         instance to :func:`save_preset` method:
@@ -209,7 +211,7 @@ class IotBulb(IotDevice):
         super().__init__(host=host, config=config, protocol=protocol)
         self._device_type = DeviceType.Bulb
 
-    async def _initialize_modules(self):
+    async def _initialize_modules(self) -> None:
         """Initialize modules not added in init."""
         await super()._initialize_modules()
         self.add_module(
@@ -303,18 +305,18 @@ class IotBulb(IotDevice):
 
     async def get_turn_on_behavior(self) -> TurnOnBehaviors:
         """Return the behavior for turning the bulb on."""
-        return TurnOnBehaviors.parse_obj(
+        return TurnOnBehaviors.from_dict(
             await self._query_helper(self.LIGHT_SERVICE, "get_default_behavior")
         )
 
-    async def set_turn_on_behavior(self, behavior: TurnOnBehaviors):
+    async def set_turn_on_behavior(self, behavior: TurnOnBehaviors) -> dict:
         """Set the behavior for turning the bulb on.
 
         If you do not want to manually construct the behavior object,
         you should use :func:`get_turn_on_behavior` to get the current settings.
         """
         return await self._query_helper(
-            self.LIGHT_SERVICE, "set_default_behavior", behavior.dict(by_alias=True)
+            self.LIGHT_SERVICE, "set_default_behavior", behavior.to_dict()
         )
 
     async def get_light_state(self) -> dict[str, dict]:
@@ -426,7 +428,7 @@ class IotBulb(IotDevice):
 
     @requires_update
     async def _set_color_temp(
-        self, temp: int, *, brightness=None, transition: int | None = None
+        self, temp: int, *, brightness: int | None = None, transition: int | None = None
     ) -> dict:
         """Set the color temperature of the device in kelvin.
 
@@ -450,7 +452,7 @@ class IotBulb(IotDevice):
 
         return await self._set_light_state(light_state, transition=transition)
 
-    def _raise_for_invalid_brightness(self, value):
+    def _raise_for_invalid_brightness(self, value: int) -> None:
         if not isinstance(value, int):
             raise TypeError("Brightness must be an integer")
         if not (0 <= value <= 100):
@@ -517,7 +519,7 @@ class IotBulb(IotDevice):
         """Return that the bulb has an emeter."""
         return True
 
-    async def set_alias(self, alias: str) -> None:
+    async def set_alias(self, alias: str) -> dict:
         """Set the device name (alias).
 
         Overridden to use a different module name.
