@@ -24,6 +24,7 @@ class LightTransition(SmartModule):
     REQUIRED_COMPONENT = "on_off_gradually"
     QUERY_GETTER_NAME = "get_on_off_gradually_info"
     MINIMUM_UPDATE_INTERVAL_SECS = 60
+    # v3 added max_duration, we default to 60 when it's not available
     MAXIMUM_DURATION = 60
 
     # Key in sysinfo that indicates state can be retrieved from there.
@@ -39,14 +40,14 @@ class LightTransition(SmartModule):
     _off_state: _State
     _enabled: bool
 
-    def __init__(self, device: SmartDevice, module: str):
+    def __init__(self, device: SmartDevice, module: str) -> None:
         super().__init__(device, module)
         self._state_in_sysinfo = all(
             key in device.sys_info for key in self.SYS_INFO_STATE_KEYS
         )
         self._supports_on_and_off: bool = self.supported_version > 1
 
-    def _initialize_features(self):
+    def _initialize_features(self) -> None:
         """Initialize features."""
         icon = "mdi:transition"
         if not self._supports_on_and_off:
@@ -90,7 +91,7 @@ class LightTransition(SmartModule):
                 )
             )
 
-    def _post_update_hook(self) -> None:
+    async def _post_update_hook(self) -> None:
         """Update the states."""
         # Assumes any device with state in sysinfo supports on and off and
         # has maximum values for both.
@@ -138,16 +139,28 @@ class LightTransition(SmartModule):
         }
 
     @allow_update_after
-    async def set_enabled(self, enable: bool):
+    async def set_enabled(self, enable: bool) -> dict:
         """Enable gradual on/off."""
         if not self._supports_on_and_off:
             return await self.call("set_on_off_gradually_info", {"enable": enable})
         else:
             on = await self.call(
-                "set_on_off_gradually_info", {"on_state": {"enable": enable}}
+                "set_on_off_gradually_info",
+                {
+                    "on_state": {
+                        "enable": enable,
+                        "duration": self._on_state["duration"],
+                    }
+                },
             )
             off = await self.call(
-                "set_on_off_gradually_info", {"off_state": {"enable": enable}}
+                "set_on_off_gradually_info",
+                {
+                    "off_state": {
+                        "enable": enable,
+                        "duration": self._off_state["duration"],
+                    }
+                },
             )
             return {**on, **off}
 
@@ -167,11 +180,10 @@ class LightTransition(SmartModule):
     @property
     def _turn_on_transition_max(self) -> int:
         """Maximum turn on duration."""
-        # v3 added max_duration, we default to 60 when it's not available
         return self._on_state["max_duration"]
 
     @allow_update_after
-    async def set_turn_on_transition(self, seconds: int):
+    async def set_turn_on_transition(self, seconds: int) -> dict:
         """Set turn on transition in seconds.
 
         Setting to 0 turns the feature off.
@@ -184,7 +196,7 @@ class LightTransition(SmartModule):
         if seconds <= 0:
             return await self.call(
                 "set_on_off_gradually_info",
-                {"on_state": {"enable": False}},
+                {"on_state": {"enable": False, "duration": self._on_state["duration"]}},
             )
 
         return await self.call(
@@ -207,7 +219,7 @@ class LightTransition(SmartModule):
         return self._off_state["max_duration"]
 
     @allow_update_after
-    async def set_turn_off_transition(self, seconds: int):
+    async def set_turn_off_transition(self, seconds: int) -> dict:
         """Set turn on transition in seconds.
 
         Setting to 0 turns the feature off.
@@ -220,7 +232,12 @@ class LightTransition(SmartModule):
         if seconds <= 0:
             return await self.call(
                 "set_on_off_gradually_info",
-                {"off_state": {"enable": False}},
+                {
+                    "off_state": {
+                        "enable": False,
+                        "duration": self._off_state["duration"],
+                    }
+                },
             )
 
         return await self.call(
@@ -236,7 +253,7 @@ class LightTransition(SmartModule):
         else:
             return {self.QUERY_GETTER_NAME: None}
 
-    async def _check_supported(self):
+    async def _check_supported(self) -> bool:
         """Additional check to see if the module is supported by the device."""
         # For devices that report child components on the parent that are not
         # actually supported by the parent.
